﻿using System.Drawing;
using System.Drawing.Drawing2D;

using Steema.TeeChart;
using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;
using Steema.TeeChart.Tools;

namespace TestProject
{
    /// <summary>
    /// 차트 헬퍼
    /// </summary>
    public class ChartHelper
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public
        ////////////////////////////////////////////////////////////////////// 그라디언트 스타일

        #region 그라디언트 스타일 설정하기 - SetGradientStyle(gradientStyle, centerXOffset, centerYOffset, pathGradientMode, visible)

        /// <summary>
        /// 그라디언트 스타일 설정하기
        /// </summary>
        /// <param name="gradientStyle">그라디언트 스타일</param>
        /// <param name="centerXOffset">중심 X 오프셋</param>
        /// <param name="centerYOffset">중심 Y 오프셋</param>
        /// <param name="pathGradientMode">경로 그라디언트 모드</param>
        /// <param name="visible">표시 여부</param>
        public static void SetGradientStyle(GradientStyle gradientStyle, int centerXOffset, int centerYOffset, PathGradientMode pathGradientMode, bool visible)
        {
            gradientStyle.CenterXOffset = centerXOffset;
            gradientStyle.CenterYOffset = centerYOffset;
            gradientStyle.Direction     = pathGradientMode;
            gradientStyle.Visible       = visible;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 그라디언트

        #region 그라디언트 설정하기 - SetGradient(gradient, startColor, middleColor, endColor, useMiddle, linearGradientMode, angle, sigma, sigmaFocus, sigmaScale, wrapMode, gammaCorrection, gradientStyle, transparency, visible)

        /// <summary>
        /// 그라디언트 설정하기
        /// </summary>
        /// <param name="gradient">그라디언트</param>
        /// <param name="startColor">시작 색상</param>
        /// <param name="middleColor">중간 색상</param>
        /// <param name="endColor">종료 색상</param>
        /// <param name="useMiddle">중간 색상 사용 여부</param>
        /// <param name="linearGradientMode">선형 그라디언트 모드</param>
        /// <param name="angle">각도</param>
        /// <param name="sigma">시그마 적용 여부</param>
        /// <param name="sigmaFocus">시그마 포커스</param>
        /// <param name="sigmaScale">시그마 스케일</param>
        /// <param name="wrapMode">랩 모드</param>
        /// <param name="gammaCorrection">감마 수정 여부</param>
        /// <param name="transparency">투명도</param>
        /// <param name="visible">표시 여부</param>
        public static void SetGradient(Gradient gradient, Color startColor, Color middleColor, Color endColor, bool useMiddle, LinearGradientMode linearGradientMode, double angle, bool sigma, float sigmaFocus, float sigmaScale, WrapMode wrapMode, bool gammaCorrection, int transparency, bool visible)
        {
            gradient.StartColor      = startColor;
            gradient.MiddleColor     = middleColor;
            gradient.EndColor        = endColor;
            gradient.UseMiddle       = useMiddle; 
            gradient.Direction       = linearGradientMode;
            gradient.Angle           = angle;
            gradient.Sigma           = sigma;
            gradient.SigmaFocus      = sigmaFocus;
            gradient.SigmaScale      = sigmaScale;
            gradient.WrapMode        = wrapMode;
            gradient.GammaCorrection = gammaCorrection;
            gradient.Transparency    = transparency;
            gradient.Visible         = visible;
        }

        #endregion
        #region 그라디언트 그라디언트 스타일 설정하기 - SetGradientGradientStyle(gradient, gradientStyle)

        /// <summary>
        /// 그라디언트 그라디언트 스타일 설정하기
        /// </summary>
        /// <param name="gradient">그라디언트</param>
        /// <param name="gradientStyle">그라디언트 스타일</param>
        public static void SetGradientGradientStyle(Gradient gradient, GradientStyle gradientStyle)
        {
            gradient.Style = gradientStyle;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 차트 브러시

        #region 차트 브러시 설정하기 - SetChartBrush(chartBrush, color, foregroundColor, image, imageMode, isImageTransparent, hatchStyle, wrapMode, transparency, visible)

        /// <summary>
        /// 차트 브러시 설정하기
        /// </summary>
        /// <param name="chartBrush">차트 브러시</param>
        /// <param name="color">색상</param>
        /// <param name="foregroundColor">전경색</param>
        /// <param name="image">이미지</param>
        /// <param name="imageMode">이미지 모드</param>
        /// <param name="isImageTransparent">이미지 투명 여부</param>
        /// <param name="hatchStyle">해치 스타일</param>
        /// <param name="wrapMode">랩 모드</param>
        /// <param name="transparency">투명도</param>
        /// <param name="visible">표시 여부</param>
        public static void SetChartBrush(ChartBrush chartBrush, Color color, Color foregroundColor, Image image, ImageMode imageMode, bool isImageTransparent, HatchStyle hatchStyle, WrapMode wrapMode, int transparency, bool visible)
        {
            chartBrush.Solid            = true;
            chartBrush.Color            = color;
            chartBrush.ForegroundColor  = foregroundColor;
            chartBrush.Image            = image;
            chartBrush.ImageMode        = imageMode;
            chartBrush.ImageTransparent = isImageTransparent;
            chartBrush.Style            = hatchStyle;
            chartBrush.WrapMode         = wrapMode;
            chartBrush.Transparency     = transparency;
            chartBrush.Visible          = visible;
        }

        #endregion
        #region 차트 브러시 그라디언트 설정하기 - SetChartBrushGradient(chartBrush, gradient)

        /// <summary>
        /// 차트 브러시 그라디언트 설정하기
        /// </summary>
        /// <param name="chartBrush">차트 브러시</param>
        /// <param name="gradient">그라디언트</param>
        public static void SetChartBrushGradient(ChartBrush chartBrush, Gradient gradient)
        {
            chartBrush.Gradient = gradient;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 그림자

        #region 그림자 설정하기 - SetShadow(shadow, width, height, color, isSmooth, smoothBlur, transparency, visible)

        /// <summary>
        /// 그림자 설정하기
        /// </summary>
        /// <param name="shadow">그림자</param>
        /// <param name="width">너비</param>
        /// <param name="height">높이</param>
        /// <param name="color">색상</param>
        /// <param name="isSmooth">스무딩 여부</param>
        /// <param name="smoothBlur">스무딩 블러</param>
        /// <param name="transparency">투명도</param>
        /// <param name="visible">표시 여부</param>
        public static void SetShadow(Shadow shadow, int width, int height, Color color, bool isSmooth, int smoothBlur, int transparency, bool visible)
        {
            shadow.Width        = width;
            shadow.Height       = height;
            shadow.Color        = color;
            shadow.Smooth       = isSmooth;
            shadow.SmoothBlur   = smoothBlur;
            shadow.Transparency = transparency;
            shadow.Visible      = visible;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 차트 폰트

        #region 차트 폰트 설정하기 - SetChartFont(chartFont, name, pointSize, color, isBold, isUnderline, isItalic, isStrikeout)

        /// <summary>
        /// 차트 폰트 설정하기
        /// </summary>
        /// <param name="chartFont">차트 폰트</param>
        /// <param name="name">폰트명</param>
        /// <param name="pointSize">포인트 크기</param>
        /// <param name="color">색상</param>
        /// <param name="isBold">볼드 여부</param>
        /// <param name="isUnderline">언더라인 여부</param>
        /// <param name="isItalic">이탤릭 여부</param>
        /// <param name="isStrikeout">중간선 여부</param>
        public static void SetChartFont(ChartFont chartFont, string name, float pointSize, Color color, bool isBold, bool isUnderline, bool isItalic, bool isStrikeout)
        {
            chartFont.Name      = name;
            chartFont.SizeFloat = pointSize;
            chartFont.Color     = color;
            chartFont.Bold      = isBold;
            chartFont.Underline = isUnderline;
            chartFont.Italic    = isItalic;
            chartFont.Strikeout = isStrikeout;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 차트 펜

        #region 차트 펜 설정하기 - SetChartPen(chartPen, color, transparency, width, dashStyle, lineCap, dashCap, visible)

        /// <summary>
        /// 차트 펜 설정하기
        /// </summary>
        /// <param name="chartPen">차트 펜</param>
        /// <param name="color">색상</param>
        /// <param name="transparency">투명도</param>
        /// <param name="width">너비</param>
        /// <param name="dashStyle">대시 스타일</param>
        /// <param name="lineCap">선 캡</param>
        /// <param name="dashCap">대시 캡</param>
        /// <param name="visible">표시 여부</param>
        public static void SetChartPen(ChartPen chartPen, Color color, int transparency, int width, DashStyle dashStyle, LineCap lineCap, DashCap dashCap, bool visible)
        {
            chartPen.Color        = color;
            chartPen.Transparency = transparency;
            chartPen.Width        = width;
            chartPen.Style        = dashStyle;
            chartPen.EndCap       = lineCap;
            chartPen.DashCap      = dashCap;
            chartPen.Visible      = visible;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 축 선 펜

        #region 축 선 펜 설정하기 - SetAxisLinePen(axisLinePen, color, transparency, width, visible)

        /// <summary>
        /// 축 선 펜 설정하기
        /// </summary>
        /// <param name="axisLinePen">축 선 펜</param>
        /// <param name="color">색상</param>
        /// <param name="transparency">투명도</param>
        /// <param name="width">너비</param>
        /// <param name="dashStyle">대시 스타일</param>
        /// <param name="lineCap">선 캡</param>
        /// <param name="dashCap">대시 캡</param>
        /// <param name="visible">표시 여부</param>
        public static void SetAxisLinePen(Axis.AxisLinePen axisLinePen, Color color, int transparency, int width, DashStyle dashStyle, LineCap lineCap, DashCap dashCap, bool visible)
        {
            axisLinePen.Color        = color;
            axisLinePen.Transparency = transparency;
            axisLinePen.Width        = width;
            axisLinePen.Style        = dashStyle;
            axisLinePen.EndCap       = lineCap;
            axisLinePen.DashCap      = dashCap;
            axisLinePen.Visible      = visible;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 눈금 펜

        #region 눈금 펜 설정하기 - SetTicksPen(ticksPen, color, transparency, width, nLength, dashStyle, lineCap, dashCap, visible)

        /// <summary>
        /// 눈금 펜 설정하기
        /// </summary>
        /// <param name="ticksPen">눈금 펜</param>
        /// <param name="color">색상</param>
        /// <param name="transparency">투명도</param>
        /// <param name="width">너비</param>
        /// <param name="nLength">길이</param>
        /// <param name="dashStyle">대시 스타일</param>
        /// <param name="lineCap">선 캡</param>
        /// <param name="dashCap">대시 캡</param>
        /// <param name="visible">표시 여부</param>
        public static void SetTicksPen(Axis.TicksPen ticksPen, Color color, int transparency, int width, int nLength, DashStyle dashStyle, LineCap lineCap, DashCap dashCap, bool visible)
        {
            ticksPen.Color        = color;
            ticksPen.Transparency = transparency;
            ticksPen.Width        = width;
            ticksPen.Length       = nLength;
            ticksPen.Style        = dashStyle;
            ticksPen.EndCap       = lineCap;
            ticksPen.DashCap      = dashCap;
            ticksPen.Visible      = visible;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 그리드 펜

        #region 그리드 펜 설정하기 - SetGridPen(gridPen, color, transparency, width, dashStyle, lineCap, dashCap, visible)

        /// <summary>
        /// 그리드 펜 설정하기
        /// </summary>
        /// <param name="gridPen">그리드 펜</param>
        /// <param name="color">색상</param>
        /// <param name="transparency">투명도</param>
        /// <param name="width">너비</param>
        /// <param name="dashStyle">대시 스타일</param>
        /// <param name="lineCap">선 캡</param>
        /// <param name="dashCap">대시 캡</param>
        /// <param name="visible">표시 여부</param>
        public static void SetGridPen(Axis.GridPen gridPen, Color color, int transparency, int width, DashStyle dashStyle, LineCap lineCap, DashCap dashCap, bool visible)
        {
            gridPen.Color        = color;
            gridPen.Transparency = transparency;
            gridPen.Width        = width;
            gridPen.Style        = dashStyle;
            gridPen.EndCap       = lineCap;
            gridPen.DashCap      = dashCap;
            gridPen.Visible      = visible;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 이미지 베벨

        #region 이미지 베벨 설정하기 - SetImageBevel(imageBevel, width, visible)

        /// <summary>
        /// 이미지 베벨 설정하기
        /// </summary>
        /// <param name="imageBevel">이미지 베벨</param>
        /// <param name="width">너비</param>
        /// <param name="visible">표시 여부</param>
        public static void SetImageBevel(ImageBevel imageBevel, int width, bool visible)
        {
            imageBevel.Width   = width;
            imageBevel.Visible = visible;
        }

        #endregion
        #region 이미지 베벨 브러시 설정하기 - SetImageBevelBrush(imageBevel, chartBrush)

        /// <summary>
        /// 이미지 베벨 브러시 설정하기
        /// </summary>
        /// <param name="imageBevel">이미지 베벨</param>
        /// <param name="chartBrush">차트 브러시</param>
        public static void SetImageBevelBrush(ImageBevel imageBevel, ChartBrush chartBrush)
        {
            imageBevel.Brush = chartBrush;
        }

        #endregion
        #region 이미지 베벨 펜 설정하기 - SetImageBevelPen(imageBevel, chartPen)

        /// <summary>
        /// 이미지 베벨 펜 설정하기
        /// </summary>
        /// <param name="imageBevel">이미지 베벨</param>
        /// <param name="chartPen">차트 펜</param>
        public static void SetImageBevelPen(ImageBevel imageBevel, ChartPen chartPen)
        {
            imageBevel.Pen = chartPen;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 베벨

        #region 베벨 설정하기 - SetBevel(bevel, colorOne, colorTwo, innerBevelStyles, outerBevelStyles, width)

        /// <summary>
        /// 베벨 설정하기
        /// </summary>
        /// <param name="bevel">베벨</param>
        /// <param name="colorOne">색상 1</param>
        /// <param name="colorTwo">색상 2</param>
        /// <param name="innerBevelStyles">내부 베벨 스타일</param>
        /// <param name="outerBevelStyles">외부 베벨 스타일</param>
        /// <param name="width">너비</param>
        public static void SetBevel(Bevel bevel, Color colorOne, Color colorTwo, BevelStyles innerBevelStyles, BevelStyles outerBevelStyles, int width)
        {
            bevel.ColorOne = colorOne;
            bevel.ColorTwo = colorTwo;
            bevel.Inner    = innerBevelStyles;
            bevel.Outer    = outerBevelStyles;
            bevel.Width    = width;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 축 제목 설정하기

        #region 축 제목 사각형 설정하기 - SetAxisTitleRectangle(axisTitle, left, top, right, bottom)

        /// <summary>
        /// 축 제목 사각형 설정하기
        /// </summary>
        /// <param name="axisTitle">축 제목</param>
        /// <param name="left">왼쪽</param>
        /// <param name="top">위쪽</param>
        /// <param name="right">오른쪽</param>
        /// <param name="bottom">아래쪽</param>
        public static void SetAxisTitleRectangle(AxisTitle axisTitle, int left, int top, int right, int bottom)
        {
            axisTitle.Left   = left;
            axisTitle.Top    = top;
            axisTitle.Right  = right;
            axisTitle.Bottom = bottom;
        }

        #endregion
        #region 축 제목 펜 설정하기 - SetAxisTitlePen(axisTitle, chartPen)

        /// <summary>
        /// 축 제목 펜 설정하기
        /// </summary>
        /// <param name="axisTitle">축 제목</param>
        /// <param name="chartPen">차트 펜</param>
        public static void SetAxisTitlePen(AxisTitle axisTitle, ChartPen chartPen)
        {
            axisTitle.Pen = chartPen;
        }

        #endregion
        #region 축 제목 브러시 설정하기 - SetAxisTitleBrush(axisTitle, chartBrush)

        /// <summary>
        /// 축 제목 브러시 설정하기
        /// </summary>
        /// <param name="axisTitle">축 제목</param>
        /// <param name="chartBrush">차트 브러시</param>
        public static void SetAxisTitleBrush(AxisTitle axisTitle, ChartBrush chartBrush)
        {
            axisTitle.Brush = chartBrush;
        }

        #endregion
        #region 축 제목 그라디언트 설정하기 - SetAxisTitleGradient(axisTitle, gradient)

        /// <summary>
        /// 축 제목 그라디언트 설정하기
        /// </summary>
        /// <param name="axisTitle">축 제목</param>
        /// <param name="gradient">그라디언트</param>
        public static void SetAxisTitleGradient(AxisTitle axisTitle, Gradient gradient)
        {
            axisTitle.Gradient = gradient;
        }

        #endregion
        #region 축 제목 폰트 설정하기 - SetAxisTitleFont(axisTitle, chartFont)

        /// <summary>
        /// 축 제목 폰트 설정하기
        /// </summary>
        /// <param name="axisTitle">축 제목</param>
        /// <param name="chartFont">차트 폰트</param>
        public static void SetAxisTitleFont(AxisTitle axisTitle, ChartFont chartFont)
        {
            axisTitle.Font = chartFont;
        }

        #endregion
        #region 축 제목 이미지 설정하기 - SetAxisTitleImage(axisTitle, image, imageMode, isImageTransparent)

        /// <summary>
        /// 축 제목 이미지 설정하기
        /// </summary>
        /// <param name="axisTitle">축 제목</param>
        /// <param name="image">이미지</param>
        /// <param name="imageMode">이미지 모드</param>
        /// <param name="isImageTransparent">이미지 투명 여부</param>
        public static void SetAxisTitleImage(AxisTitle axisTitle, Image image, ImageMode imageMode, bool isImageTransparent)
        {
            axisTitle.Image            = image;
            axisTitle.ImageMode        = imageMode;
            axisTitle.ImageTransparent = isImageTransparent;
        }

        #endregion
        #region 축 제목 설정하기 - SetAxisTitle(axisTitle, isAutoSize, textShapeStyle, width, height, borderRound, color, angle, isClipText, text, stringAlignment, textFormat, transparency, isTransparent, visible)

        /// <summary>
        /// 축 제목 설정하기
        /// </summary>
        /// <param name="axisTitle">축 제목</param>
        /// <param name="isAutoSize">자동 크기 여부</param>
        /// <param name="textShapeStyle">텍스트 도형 종류</param>
        /// <param name="width">너비</param>
        /// <param name="height">크기</param>
        /// <param name="borderRound">경계선 라운드</param>
        /// <param name="color">색상</param>
        /// <param name="angle">각도</param>
        /// <param name="isClipText">텍스트 클리핑 여부</param>
        /// <param name="stringAlignment">문자열 정렬</param>
        /// <param name="textFormat">텍스트 형식</param>
        /// <param name="text">텍스트</param>
        /// <param name="transparency">투명도</param>
        /// <param name="isTransparent">투명 표시 여부</param>
        /// <param name="visible">표시 여부</param>
        public static void SetAxisTitle(AxisTitle axisTitle, bool isAutoSize, TextShapeStyle textShapeStyle, int width, int height, int borderRound, Color color, int angle, bool isClipText, string text, StringAlignment stringAlignment, TextFormat textFormat, int transparency, bool isTransparent, bool visible)
        {
            axisTitle.AutoSize     = isAutoSize;
            axisTitle.ShapeStyle   = textShapeStyle;
            axisTitle.Width        = width;
            axisTitle.Height       = height;
            axisTitle.BorderRound  = borderRound;
            axisTitle.Color        = color;
            axisTitle.Angle        = angle;
            axisTitle.ClipText     = isClipText;
            axisTitle.TextAlign    = stringAlignment;
            axisTitle.TextFormat   = textFormat;
            axisTitle.Text         = text;
            axisTitle.Transparency = transparency;
            axisTitle.Transparent  = isTransparent;
            axisTitle.Visible      = visible;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 축 설정하기

        #region 축 설정하기 - SetAxis(Axis axis, bool isHorizontal, bool isOtherSide, double increment, bool isLogarithmic, double logarithmicBase, double zPosition, bool visible)

        /// <summary>
        /// 축 설정하기
        /// </summary>
        /// <param name="axis">축</param>
        /// <param name="isHorizontal">수평 여부</param>
        /// <param name="isOtherSide">반대편 여부</param>
        /// <param name="increment">레이블 표시 간격</param>
        /// <param name="isLogarithmic">눈금 로그 표시 여부</param>
        /// <param name="logarithmicBase">로그 베이스</param>
        /// <param name="zPosition">Z 위치</param>
        /// <param name="visible">표시 여부</param>
        public static void SetAxis(Axis axis, bool isHorizontal, bool isOtherSide, double increment, bool isLogarithmic, double logarithmicBase, double zPosition, bool visible)
        {
            axis.Horizontal      = isHorizontal;
            axis.OtherSide       = isOtherSide;
            axis.Increment       = increment;
            axis.Logarithmic     = isLogarithmic;
            axis.LogarithmicBase = logarithmicBase;
            axis.ZPosition       = zPosition;
            axis.Visible         = visible;
        }

        #endregion
        #region 축 제목 설정하기 - SetAxisTitle(axis, axisTitle)

        /// <summary>
        /// 축 제목 설정하기
        /// </summary>
        /// <param name="axis">축</param>
        /// <param name="axisTitle">축 제목</param>
        public static void SetAxisTitle(Axis axis, AxisTitle axisTitle)
        {
            axis.Title = axisTitle;
        }

        #endregion
        #region 축 펜 설정하기 - SetAxisPen(axis, axisLinePen)

        /// <summary>
        /// 축 펜 설정하기
        /// </summary>
        /// <param name="axis">축</param>
        /// <param name="axisLinePen">축 선 펜</param>
        public static void SetAxisPen(Axis axis, Axis.AxisLinePen axisLinePen)
        {
            axis.AxisPen = axisLinePen;
        }

        #endregion
        #region 축 눈금 설정하기 - SetAxisTicks(axis, ticksPen, isTickOnLabelsOnly)

        /// <summary>
        /// 축 눈금 설정하기
        /// </summary>
        /// <param name="axis">축</param>
        /// <param name="ticksPen">눈금 펜</param>
        /// <param name="isTickOnLabelsOnly">레이블 위에 눈금 표시 여부</param>
        public static void SetAxisTicks(Axis axis, Axis.TicksPen ticksPen, bool isTickOnLabelsOnly)
        {
            axis.Ticks            = ticksPen;
            axis.TickOnLabelsOnly = isTickOnLabelsOnly;
        }

        #endregion
        #region 축 그리드 설정하기 - SetAxisGrid(axis, gridPen)

        /// <summary>
        /// 축 그리드 설정하기
        /// </summary>
        /// <param name="axis">축</param>
        /// <param name="gridPen">그리드 펜</param>
        public static void SetAxisGrid(Axis axis, Axis.GridPen gridPen)
        {
            axis.Grid = gridPen;
        }

        #endregion
        #region 축 보조 눈금 설정하기 - SetAxisMinorTicks(axis, ticksPen, tickCount)

        /// <summary>
        /// 축 보조 눈금 설정하기
        /// </summary>
        /// <param name="axis">축</param>
        /// <param name="ticksPen">눈금 펜</param>
        /// <param name="tickCount">눈금 수</param>
        public static void SetAxisMinorTicks(Axis axis, Axis.TicksPen ticksPen, int tickCount)
        {
            axis.MinorTicks     = ticksPen;
            axis.MinorTickCount = tickCount;
        }

        #endregion
        #region 축 보조 그리드 설정하기 - SetAxisMinorGrid(axis, chartPen)

        /// <summary>
        /// 축 보조 그리드 설정하기
        /// </summary>
        /// <param name="axis">축</param>
        /// <param name="chartPen">차트 펜</param>
        public static void SetAxisMinorGrid(Axis axis, ChartPen chartPen)
        {
            axis.MinorGrid = chartPen;
        }

        #endregion
        #region 축 범위 설정하기 - SetAxisRange(axis, isInverted, isAutomaticMinimum, minimumOffset, isMinimumRound, minimum, isAutomaticMaximum, maximumOffset, isMaximumRound, maximum)

        /// <summary>
        /// 축 범위 설정하기
        /// </summary>
        /// <param name="axis">축</param>
        /// <param name="isInverted">반전 여부</param>
        /// <param name="isAutomaticMinimum">최소값 자동 설정</param>
        /// <param name="minimumOffset">최소값 오프셋</param>
        /// <param name="isMinimumRound">최소값 반올림 여부</param>
        /// <param name="minimum">최소값</param>
        /// <param name="isAutomaticMaximum">최대값 자동 설정</param>
        /// <param name="maximumOffset">최대값 오프셋</param>
        /// <param name="isMaximumRound">최대값 반올림 여부</param>
        /// <param name="maximum">최대값</param>
        public static void SetAxisRange(Axis axis, bool isInverted, bool isAutomaticMinimum, int minimumOffset, bool isMinimumRound, double minimum, bool isAutomaticMaximum, int maximumOffset, bool isMaximumRound, double maximum)
        {
            axis.Inverted         = isInverted;
            axis.Automatic        = isAutomaticMinimum && isAutomaticMaximum;

            axis.AutomaticMinimum = isAutomaticMinimum;
            axis.MinimumOffset    = minimumOffset;
            axis.MinimumRound     = isMinimumRound;

            if(!isAutomaticMinimum)
            {
                axis.Minimum = minimum;                
            }

            axis.AutomaticMaximum = isAutomaticMaximum;
            axis.MaximumOffset    = maximumOffset;
            axis.MaximumRound     = isMaximumRound;

            if(!isAutomaticMaximum)
            {
                axis.Maximum = maximum;
            }
        }

        #endregion
        #region 축 위치 설정하기 - SetAxisPosition(axis, positionUnits, startPosition, endPosition)

        /// <summary>
        /// 축 위치 설정하기
        /// </summary>
        /// <param name="axis">축</param>
        /// <param name="positionUnits">위치 단위</param>
        /// <param name="startPosition">시작 위치</param>
        /// <param name="endPosition">종료 위치</param>
        public static void SetAxisPosition(Axis axis, PositionUnits positionUnits, double startPosition, double endPosition)
        {
            axis.StartEndPositionUnits = positionUnits;
            axis.StartPosition         = startPosition;
            axis.EndPosition           = endPosition;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 왼쪽/위쪽/오른쪽/아래쪽 축 설정하기

        #region 왼쪽 축 설정하기 - SetLeftAxis(tChart)

        /// <summary>
        /// 왼쪽 축 설정하기
        /// </summary>
        /// <param name="tChart">티차트</param>
        public static void SetLeftAxis(TChart tChart)
        {
            Axis axis = tChart.Axes.Left;

            SetAxisLinePen(axis.AxisPen, Color.Black, 0, 1, DashStyle.Solid, LineCap.Round, DashCap.Round, true);

            SetAxisRange(axis, false, true, 5, false, 0d, true, 5, false, 0d);
        }

        #endregion
        #region 위쪽 축 설정하기 - SetToaxis(tChart)

        /// <summary>
        /// 위쪽 축 설정하기
        /// </summary>
        /// <param name="tChart">티차트</param>
        public static void SetToaxis(TChart tChart)
        {
            Axis axis = tChart.Axes.Top;

            SetAxisLinePen(axis.AxisPen, Color.Black, 0, 1, DashStyle.Solid, LineCap.Round, DashCap.Round, true);
        }

        #endregion
        #region 오른쪽 축 설정하기 - SetRightAxis(tChart)

        /// <summary>
        /// 오른쪽 축 설정하기
        /// </summary>
        /// <param name="tChart">티차트</param>
        public static void SetRightAxis(TChart tChart)
        {
            Axis axis = tChart.Axes.Right;

            SetAxisLinePen(axis.AxisPen, Color.Black, 0, 1, DashStyle.Solid, LineCap.Round, DashCap.Round, true);
        }

        #endregion
        #region 아래쪽 축 설정하기 - SetBottomAxis(tChart)

        /// <summary>
        /// 아래쪽 축 설정하기
        /// </summary>
        /// <param name="tChart">티차트</param>
        public static void SetBottomAxis(TChart tChart)
        {
            Axis axis = tChart.Axes.Bottom;

            SetAxisLinePen(axis.AxisPen, Color.Black, 0, 1, DashStyle.Solid, LineCap.Round, DashCap.Round, true);

            SetAxisRange(axis, false, true, 5, false, 0d, true, 5, false, 0d);
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 머리말

        #region 머리말 설정하기 - SetHeader(header, stringAlignment, isAutoSize, isAdjustFrame, textShapeStyle, borderRound, color, isClipText, textStringAlignment, textFormat, transparency, isTransparent, visible)

        /// <summary>
        /// 머리말 설정하기
        /// </summary>
        /// <param name="header">머리말</param>
        /// <param name="stringAlignment">문자열 정렬</param>
        /// <param name="isAutoSize">자동 크기 여부</param>
        /// <param name="isAdjustFrame">프레임 조정 여부</param>
        /// <param name="textShapeStyle">텍스트 도형 종류</param>
        /// <param name="borderRound">경계선 라운드</param>
        /// <param name="color">색상</param>
        /// <param name="isClipText">텍스트 클리핑 여부</param>
        /// <param name="textStringAlignment">텍스트 문자열 정렬</param>
        /// <param name="textFormat">텍스트 형식</param>
        /// <param name="transparency">투명도</param>
        /// <param name="isTransparent">투명 표시 여부</param>
        /// <param name="visible">표시 여부</param>
        public static void SetHeader(Header header, StringAlignment stringAlignment, bool isAutoSize, bool isAdjustFrame, TextShapeStyle textShapeStyle, int borderRound, Color color, bool isClipText, StringAlignment textStringAlignment, TextFormat textFormat, int transparency, bool isTransparent, bool visible)
        {
            header.Alignment    = stringAlignment;
            header.AutoSize     = isAutoSize;
            header.AdjustFrame  = isAdjustFrame;
            header.ShapeStyle   = textShapeStyle;
            header.BorderRound  = borderRound;
            header.Color        = color;
            header.ClipText     = isClipText;
            header.TextAlign    = textStringAlignment;
            header.TextFormat   = textFormat;
            header.Transparency = transparency;
            header.Transparent  = isTransparent;
            header.Visible      = visible;
        }

        #endregion
        #region 머리말 텍스트 설정하기 - SetHeaderText(header, text)

        /// <summary>
        /// 머리말 텍스트 설정하기
        /// </summary>
        /// <param name="header">머리말</param>
        /// <param name="text">텍스트</param>
        public static void SetHeaderText(Header header, string text)
        {
            header.Text = text;
        }

        #endregion
        #region 머리말 사각형 설정하기 - SetHeaderRectangle(header, isCustomPosition, left, top, right, bottom)

        /// <summary>
        /// 머리말 사각형 설정하기
        /// </summary>
        /// <param name="header">머리말</param>
        /// <param name="isCustomPosition">사용자 정의 위치 여부</param>
        /// <param name="left">왼쪽</param>
        /// <param name="top">위쪽</param>
        /// <param name="right">오른쪽</param>
        /// <param name="bottom">아래쪽</param>
        public static void SetHeaderRectangle(Header header, bool isCustomPosition, int left, int top, int right, int bottom)
        {
            header.CustomPosition = isCustomPosition;
            header.Left           = left;
            header.Top            = top;
            header.Right          = right;
            header.Bottom         = bottom;
        }

        #endregion
        #region 머리말 폰트 설정하기 - SetHeaderFont(header, chartFont)

        /// <summary>
        /// 머리말 폰트 설정하기
        /// </summary>
        /// <param name="header">머리말</param>
        /// <param name="chartFont">차트 폰트</param>
        public static void SetHeaderFont(Header header, ChartFont chartFont)
        {
            header.Font = chartFont;
        }

        #endregion
        #region 머리말 펜 설정하기 - SetHeaderPen(header, chartPen)

        /// <summary>
        /// 머리말 펜 설정하기
        /// </summary>
        /// <param name="header">머리말</param>
        /// <param name="chartPen">차트 펜</param>
        public static void SetHeaderPen(Header header, ChartPen chartPen)
        {
            header.Pen = chartPen;
        }

        #endregion
        #region 머리말 브러시 설정하기 - SetHeaderBrush(header, chartBrush)

        /// <summary>
        /// 머리말 브러시 설정하기
        /// </summary>
        /// <param name="header">머리말</param>
        /// <param name="chartBrush">차트 브러시</param>
        public static void SetHeaderBrush(Header header, ChartBrush chartBrush)
        {
            header.Brush = chartBrush;
        }

        #endregion
        #region 머리말 그라디언트 설정하기 - SetHeaderBrush(header, gradient)

        /// <summary>
        /// 머리말 그라디언트 설정하기
        /// </summary>
        /// <param name="header">머리말</param>
        /// <param name="gradient">그라디언트</param>
        public static void SetHeaderBrush(Header header, Gradient gradient)
        {
            header.Gradient = gradient;
        }

        #endregion
        #region 머리말 이미지 설정하기 - SetHeaderImage(header, image, imageMode, isImageTransparent)

        /// <summary>
        /// 머리말 이미지 설정하기
        /// </summary>
        /// <param name="header">머리말</param>
        /// <param name="image">이미지</param>
        /// <param name="imageMode">이미지 모드</param>
        /// <param name="isImageTransparent">이미지 투명 여부</param>
        public static void SetHeaderImage(Header header, Image image, ImageMode imageMode, bool isImageTransparent)
        {
            header.Image            = image;
            header.ImageMode        = imageMode;
            header.ImageTransparent = isImageTransparent;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 꼬리말

        #region 꼬리말 설정하기 - SetFooter(footer, stringAlignment, isAutoSize, isAdjustFrame, textShapeStyle, borderRound, color, isClipText, textStringAlignment, textFormat, transparency, isTransparent, visible)

        /// <summary>
        /// 꼬리말 설정하기
        /// </summary>
        /// <param name="footer">꼬리말</param>
        /// <param name="stringAlignment">문자열 정렬</param>
        /// <param name="isAutoSize">자동 크기 여부</param>
        /// <param name="isAdjustFrame">프레임 조정 여부</param>
        /// <param name="textShapeStyle">텍스트 도형 종류</param>
        /// <param name="borderRound">경계선 라운드</param>
        /// <param name="color">색상</param>
        /// <param name="isClipText">텍스트 클리핑 여부</param>
        /// <param name="textStringAlignment">텍스트 문자열 정렬</param>
        /// <param name="textFormat">텍스트 형식</param>
        /// <param name="transparency">투명도</param>
        /// <param name="isTransparent">투명 표시 여부</param>
        /// <param name="visible">표시 여부</param>
        public static void SetFooter(Footer footer, StringAlignment stringAlignment, bool isAutoSize, bool isAdjustFrame, TextShapeStyle textShapeStyle, int borderRound, Color color, bool isClipText, StringAlignment textStringAlignment, TextFormat textFormat, int transparency, bool isTransparent, bool visible)
        {
            footer.Alignment    = stringAlignment;
            footer.AutoSize     = isAutoSize;
            footer.AdjustFrame  = isAdjustFrame;
            footer.ShapeStyle   = textShapeStyle;
            footer.BorderRound  = borderRound;
            footer.Color        = color;
            footer.ClipText     = isClipText;
            footer.TextAlign    = textStringAlignment;
            footer.TextFormat   = textFormat;
            footer.Transparency = transparency;
            footer.Transparent  = isTransparent;
            footer.Visible      = visible;
        }

        #endregion
        #region 꼬리말 텍스트 설정하기 - SetFooterText(footer, text)

        /// <summary>
        /// 꼬리말 텍스트 설정하기
        /// </summary>
        /// <param name="footer">꼬리말</param>
        /// <param name="text">텍스트</param>
        public static void SetFooterText(Footer footer, string text)
        {
            footer.Text = text;
        }

        #endregion
        #region 꼬리말 폰트 설정하기 - SetFooterFont(footer, chartFont)

        /// <summary>
        /// 꼬리말 폰트 설정하기
        /// </summary>
        /// <param name="footer">꼬리말</param>
        /// <param name="chartFont">차트 폰트</param>
        public static void SetFooterFont(Footer footer, ChartFont chartFont)
        {
            footer.Font = chartFont;
        }

        #endregion
        #region 꼬리말 펜 설정하기 - SetFooterPen(footer, chartPen)

        /// <summary>
        /// 꼬리말 펜 설정하기
        /// </summary>
        /// <param name="footer">꼬리말</param>
        /// <param name="chartPen">차트 펜</param>
        public static void SetFooterPen(Footer footer, ChartPen chartPen)
        {
            footer.Pen = chartPen;
        }

        #endregion
        #region 꼬리말 브러시 설정하기 - SetFooterBrush(footer, chartBrush)

        /// <summary>
        /// 꼬리말 브러시 설정하기
        /// </summary>
        /// <param name="footer">꼬리말</param>
        /// <param name="chartBrush">차트 브러시</param>
        public static void SetFooterBrush(Footer footer, ChartBrush chartBrush)
        {
            footer.Brush = chartBrush;
        }

        #endregion
        #region 꼬리말 그라디언트 설정하기 - SetFooterBrush(footer, gradient)

        /// <summary>
        /// 꼬리말 그라디언트 설정하기
        /// </summary>
        /// <param name="footer">꼬리말</param>
        /// <param name="gradient">그라디언트</param>
        public static void SetFooterBrush(Footer footer, Gradient gradient)
        {
            footer.Gradient = gradient;
        }

        #endregion
        #region 꼬리말 이미지 설정하기 - SetFooterImage(footer, image, imageMode, isImageTransparent)

        /// <summary>
        /// 꼬리말 이미지 설정하기
        /// </summary>
        /// <param name="footer">꼬리말</param>
        /// <param name="image">이미지</param>
        /// <param name="imageMode">이미지 모드</param>
        /// <param name="isImageTransparent">이미지 투명 여부</param>
        public static void SetFooterImage(Footer footer, Image image, ImageMode imageMode, bool isImageTransparent)
        {
            footer.Image            = image;
            footer.ImageMode        = imageMode;
            footer.ImageTransparent = isImageTransparent;
        }

        #endregion
        #region 꼬리말 설정하기 - SetFooter(footer, stringAlignment, isAutoSize, isAdjustFrame, textShapeStyle, borderRound, color, isClipText, textStringAlignment, textFormat, text, transparency, isTransparent, visible)

        /// <summary>
        /// 꼬리말 설정하기
        /// </summary>
        /// <param name="footer">꼬리말</param>
        /// <param name="stringAlignment">문자열 정렬</param>
        /// <param name="isAutoSize">자동 크기 여부</param>
        /// <param name="isAdjustFrame">프레임 조정 여부</param>
        /// <param name="textShapeStyle">텍스트 도형 종류</param>
        /// <param name="borderRound">경계선 라운드</param>
        /// <param name="color">색상</param>
        /// <param name="isClipText">텍스트 클리핑 여부</param>
        /// <param name="textStringAlignment">텍스트 문자열 정렬</param>
        /// <param name="textFormat">텍스트 형식</param>
        /// <param name="text">텍스트</param>
        /// <param name="transparency">투명도</param>
        /// <param name="isTransparent">투명 표시 여부</param>
        /// <param name="visible">표시 여부</param>
        public static void SetFooter(Footer footer, StringAlignment stringAlignment, bool isAutoSize, bool isAdjustFrame, TextShapeStyle textShapeStyle, int borderRound, Color color, bool isClipText, StringAlignment textStringAlignment, TextFormat textFormat, string text, int transparency, bool isTransparent, bool visible)
        {
            footer.Alignment    = stringAlignment;
            footer.AutoSize     = isAutoSize;
            footer.AdjustFrame  = isAdjustFrame;
            footer.ShapeStyle   = textShapeStyle;
            footer.BorderRound  = borderRound;
            footer.Color        = color;
            footer.ClipText     = isClipText;
            footer.TextAlign    = textStringAlignment;
            footer.TextFormat   = textFormat;
            footer.Text         = text;
            footer.Transparency = transparency;
            footer.Transparent  = isTransparent;
            footer.Visible      = visible;
        }

        #endregion

        ////////////////////////////////////////////////////////////////////// 티차트

        #region TChart 객체 구하기 - GetTChart(headerCaption, footerCaption, xAxisCaption, yAxisCaption)

        /// <summary>
        /// TChart 객체 구하기
        /// </summary>
        /// <param name="headerCaption">머리말 제목</param>
        /// <param name="footerCaption">꼬리말 제목</param>
        /// <param name="xAxisCaption">X축 제목</param>
        /// <param name="yAxisCaption">Y축 제목</param>
        /// <returns>TChart 객체</returns>
        public static TChart GetTChart(string headerCaption, string footerCaption, string xAxisCaption, string yAxisCaption)
        {
            TChart tChart = new TChart();

            #region Aspect를 설정한다.

            tChart.Aspect.View3D  = false;
            tChart.Aspect.ZOffset = 0;

            #endregion

            #region Axes.Bottom을 설정한다.

            tChart.Axes.Bottom.AxisPen.Width         = 1;
            tChart.Axes.Bottom.Labels.Angle          = 90;
            tChart.Axes.Bottom.Labels.Font.SizeFloat = 7f;
            tChart.Axes.Bottom.MaximumOffset         = 5;
            tChart.Axes.Bottom.MinimumOffset         = 5;

            if(!string.IsNullOrEmpty(xAxisCaption))
            {
                tChart.Axes.Bottom.Title.Text = xAxisCaption;
            }

            #endregion

            #region Axes.Left를 설정한다.

            tChart.Axes.Left.AxisPen.Width         = 1;
            tChart.Axes.Left.MaximumOffset         = 5;
            tChart.Axes.Left.MinimumOffset         = 5;
            tChart.Axes.Left.Labels.Font.SizeFloat = 7f;

            if(!string.IsNullOrEmpty(yAxisCaption))
            {
                tChart.Axes.Left.Title.Text = yAxisCaption;
            }

            #endregion

            #region Axes.Right를 설정한다.

            tChart.Axes.Right.AxisPen.Width = 1;
            tChart.Axes.Right.MaximumOffset = 5;
            tChart.Axes.Right.MinimumOffset = 5;

            #endregion

            #region Axes.Top을 설정한다.

            tChart.Axes.Top.AxisPen.Width = 1;
            tChart.Axes.Top.MaximumOffset = 5;
            tChart.Axes.Top.MinimumOffset = 5;

            #endregion

            #region Footer를 설정한다.

            tChart.Footer.Font.SizeFloat = 9f;

            if(string.IsNullOrEmpty(footerCaption))
            {
                tChart.Footer.Visible = false;
            }
            else
            {
                tChart.Footer.Lines   = new string[] { footerCaption };
                tChart.Footer.Visible = true;
            }

            #endregion

            #region Header를 설정한다.

            tChart.Header.Font.SizeFloat = 11f;

            if(string.IsNullOrEmpty(headerCaption))
            {
                tChart.Header.Visible = false;
            }
            else
            {
                tChart.Header.Lines   = new string[] { headerCaption };
                tChart.Header.Visible = true;
            }

            #endregion

            #region Legend를 설정한다.

            tChart.Legend.Alignment   = LegendAlignments.Top;
            tChart.Legend.CheckBoxes  = true;
            tChart.Legend.LegendStyle = LegendStyles.Series;

            #endregion

            #region Panel을 설정한다.

            tChart.Panel.Bevel.Outer            = BevelStyles.None;
            tChart.Panel.Brush.Color            = Color.White;
            tChart.Panel.Brush.Gradient.Visible = false;

            #endregion

            #region Walls를 설정한다.

            tChart.Walls.Back.Brush.Color            = Color.White;
            tChart.Walls.Back.Brush.Gradient.Visible = false;

            #endregion

            return tChart;
        }

        #endregion
        #region Line 객체 구하기 - GetLine(caption, useEachColor, color, pointerStyles, useDateTimeAxis, linePewidth, showInLegend)

        /// <summary>
        /// Line 객체 구하기
        /// </summary>
        /// <param name="caption">제목</param>
        /// <param name="color">색상</param>
        /// <param name="useEachColor">개별 색상 사용 여부</param>
        /// <param name="pointerStyles">포인터 스타일</param>
        /// <param name="useDateTimeAxis">시간 축 사용 여부</param>
        /// <param name="linePewidth">라인 펜 너비</param>
        /// <param name="showInLegend">레전드 표시 여부</param>
        /// <returns>Line 객체</returns>
        public static Line GetLine(string caption, bool useEachColor, Color color, PointerStyles pointerStyles, bool useDateTimeAxis, int linePewidth, bool showInLegend)
        {
            Line pLine = new Line();

            pLine.Brush.Color           = color;
            pLine.Color                 = color;
            pLine.ColorEach             = useEachColor;
            pLine.LinePen.Color         = color;
            pLine.LinePen.Width         = linePewidth;
            pLine.Marks.Callout.Visible = false;
            pLine.Pointer.Pen.Visible   = false;
            pLine.Pointer.Style         = pointerStyles;
            pLine.Pointer.Visible       = true;
            pLine.ShowInLegend          = showInLegend;
            pLine.Title                 = caption;
            pLine.XValues.DateTime      = useDateTimeAxis;
            pLine.XValues.Order         = ValueListOrder.None;

            switch(pointerStyles)
            {
                case PointerStyles.Rectangle :

                    pLine.Pointer.HorizSize = 3;
                    pLine.Pointer.VertSize  = 3;

                    break;
            }
 
            return pLine;
        }

        #endregion
        #region Points 객체 구하기 - GetPoints(caption, useEachColor, color, pointerStyles, useDateTimeAxis, showInLegend)

        /// <summary>
        /// Points 객체 구하기
        /// </summary>
        /// <param name="caption">제목</param>
        /// <param name="useEachColor">개별 색상 사용 여부</param>
        /// <param name="color">색상</param>
        /// <param name="pointerStyles">포인터 스타일</param>
        /// <param name="useDateTimeAxis">시간 축 사용 여부</param>
        /// <param name="showInLegend">레전드 표시 여부</param>
        /// <returns></returns>
        public static Points GetPoints(string caption, bool useEachColor, Color color, PointerStyles pointerStyles, bool useDateTimeAxis, bool showInLegend)
        {
            Points points = new Points();

            points.Color                 = color;
            points.ColorEach             = useEachColor;
            points.LinePen.Color         = color;
            points.Marks.Callout.Visible = false;
            points.Pointer.Pen.Visible   = false;
            points.Pointer.Style         = pointerStyles;
            points.Pointer.Visible       = true;
            points.ShowInLegend          = showInLegend;
            points.Title                 = caption;
            points.XValues.DateTime      = useDateTimeAxis;
            points.XValues.Order         = ValueListOrder.None;

            switch(pointerStyles)
            {
                case PointerStyles.Rectangle :

                    points.Pointer.HorizSize = 3;
                    points.Pointer.VertSize  = 3;

                    break;
            }

            return points;
        }

        #endregion
        #region Bar 객체 구하기 - GetBar(caption, useEachColor, color, useDateTimeAxis, showInLegend)

        /// <summary>
        /// Bar 객체 구하기
        /// </summary>
        /// <param name="caption">제목</param>
        /// <param name="useEachColor">개별 색상 사용 여부</param>
        /// <param name="color">색상</param>
        /// <param name="useDateTimeAxis">시간 축 사용 여부</param>
        /// <param name="showInLegend">레전드 표시 여부</param>
        /// <returns>Bar 객체</returns>
        public static Bar GetBar(string caption, bool useEachColor, Color color, bool useDateTimeAxis, bool showInLegend)
        {
            Bar bar = new Bar();

            bar.Brush.Color                 = color;
            bar.Color                       = color;
            bar.ColorEach                   = useEachColor;
            bar.Marks.Callout.ArrowHead     = ArrowHeadStyles.None;
            bar.Marks.Callout.ArrowHeadSize = 8;
            bar.Marks.Callout.Brush.Color   = Color.Black;
            bar.Marks.Callout.Distance      = 0;
            bar.Marks.Callout.Draw3D        = false;
            bar.Marks.Callout.Length        = 20;
            bar.Marks.Callout.Style         = PointerStyles.Rectangle;
            bar.Marks.Callout.Visible       = false;
            bar.Marks.Visible               = false;
            bar.Pen.Color                   = color;
            bar.ShowInLegend                = showInLegend;
            bar.Title                       = caption;
            bar.XValues.DateTime            = useDateTimeAxis;
            bar.XValues.Order               = ValueListOrder.None;

            return bar;
        }

        #endregion
        #region ColorLine 객체 구하기 - GetColorLine(axis, color, penTransparency, penWidth, value)

        /// <summary>
        /// ColorLine 객체 구하기
        /// </summary>
        /// <param name="axis">축</param>
        /// <param name="color">색상</param>
        /// <param name="penTransparency">펜 투명도</param>
        /// <param name="penWidth">펜 너비</param>
        /// <param name="value">값</param>
        /// <returns>ColorLine 객체</returns>
        public static ColorLine GetColorLine(Axis axis, Color color, int penTransparency, int penWidth, double value)
        {
            ColorLine colorLine = new ColorLine();

            colorLine.AllowDrag        = false;
            colorLine.Axis             = axis;
            colorLine.Pen.Color        = color;
            colorLine.Pen.Transparency = penTransparency;
            colorLine.Pen.Width        = penWidth;
            colorLine.Value            = value;

            return colorLine;
        }

        #endregion
    }
}